CIF Validation web interface
Author: James Hester
Description: Form for inputting CIF files for validation

## CIF file validation server

CIF or dictionary file for validation: |  | Is this file a DDL2 dictionary? |
Dictionary/dictionaries to validate against: |

*: Uses a DDL1 dictionary where the `_type_construct` attribute for `_enumeration_range` has been changed from `(_sequence_minimum):((_sequence_maximum)?)` to `[A-Za-z0-9+%^#@-]+:[A-Za-z0-9+%^#@-]?`. The as-written attribute value is not machine-readable and therefore produces a lot of validation warnings.

## Background

This is an experimental web-based interface for validating CIF files using the PyCIFRW package described in J. Appl. Cryst. 39, 621---625. Using this interface, you should be able to:

- Validate a DDL1-style data CIF against the listed DDL1 dictionaries;
- Validate a DDL2-style data CIF against the listed DDL2 dictionaries;
- Validate a DDL1-style data CIF against the listed DDL2 dictionaries;
- Validate a DDL1/2 CIF dictionary against an appropriate DDL1/2 dictionary;

Please note that there is a file-size limit of 100K, and that files containing syntax errors will not currently produce an informative error report.

If you are able to produce an error message using a syntactically correct CIF file, or if you disagree with an assessment of block validity, please forward your comments and the error to `jrh at anbf2 dot kek dot jp`.